@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Attribute.h,v 1.3 1999/02/02 18:22:39 gritton Exp $
+ * $Id: Attribute.h,v 1.1 2004/08/28 19:25:46 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -25,7 +26,10 @@
  *                    codesmit@southwind.net
  *
 */
-#include <stdlib.h>
+
+#ifndef _ATTRIBUTE_H
+#define _ATTRIBUTE_H
+
 #include "Expression.h"
 #include "ExpressionList.h"
 
@@ -41,3 +45,6 @@ ExpressionElement *AttributeListErase(AttributeList *, ExpressionElement *);
 void AttributeListAppend(AttributeList *this, ExpressionElement *expr);
 void AttributeListAppendLists(AttributeList *this, AttributeList *list);
 void AttributeListEmit(AttributeList *this);
+
+#endif /* _ATTRIBUTE_H */
+
