@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DebugUtil.h,v 1.45 2002/03/29 16:46:27 amai Exp $
+ * $Id: DebugUtil.h,v 1.1 2004/08/28 19:23:29 dannybackx Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2002 LessTif Development Team
@@ -26,7 +26,7 @@
 #ifndef _XMI_DEBUGUTIL_H
 #define _XMI_DEBUGUTIL_H
 
-#include <LTconfig.h>
+/* #include <LTconfig.h> */
 
 #include <Xm/XmP.h>
 
