@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DebugUtil.c,v 1.95 2002/04/12 23:38:43 amai Exp $
+ * $Id: DebugUtil.c,v 1.4 2004/09/26 13:05:57 dannybackx Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2002 LessTif Development Team 
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DebugUtil.c,v 1.95 2002/04/12 23:38:43 amai Exp $";
+static const char rcsid[] = "$Id: DebugUtil.c,v 1.4 2004/09/26 13:05:57 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -632,6 +632,9 @@ static const struct
     }
     ,
 #endif
+    {
+	    XmNacceleratorText,	_LtDebugXMSTRING,	NULL
+    },
     {
 	NULL, 0, NULL
     }				/* the end */
@@ -1940,6 +1943,21 @@ _LtDebugWidgetGeometry2String(XtWidgetGeometry *g)
     }
 
     out[0] = '\0';
+#if 0
+    {
+	char	t[16];
+	strcat(out, "{");
+	sprintf(t, "%d,", g->request_mode);
+	strcat(out, t);
+	if (g->request_mode & CWX) strcat(out, "x");
+	if (g->request_mode & CWY) strcat(out, "y");
+	if (g->request_mode & CWWidth) strcat(out, "w");
+	if (g->request_mode & CWHeight) strcat(out, "h");
+	if (g->request_mode & CWBorderWidth) strcat(out, "b");
+	strcat(out, "} ");
+    }
+#endif
+
     if (g->request_mode & CWX)
     {
 	sprintf(b, "x %d ", g->x);
@@ -2494,3 +2512,25 @@ _LtDebugFree(const char *f, int l, XtPointer p)
     }
 #endif
 }
+
+/*
+ * Only include this when necessary.
+ * What is this really dependent on ?
+ */
+extern void
+_LtDebugPrintStackTrace()
+{
+#ifdef HAVE_BACKTRACE
+	void	*trace[32];
+	char	**messages = (char **)0;
+	int	i, trace_size = 0;
+
+	_LtDebugInit();
+	trace_size = backtrace(trace, 32);
+	messages = (char **)backtrace_symbols(trace, trace_size);
+	fprintf(_LtDebugFile, "[bt] Stack trace\n");
+	for (i=0; i<trace_size; i++)
+		fprintf(_LtDebugFile, "\t[%s]\n", messages[i]);
+	fflush(_LtDebugFile);
+#endif
+}
