@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/FontList.c,v 1.50 2002/11/22 18:37:24 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/FontList.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: FontList.c,v 1.50 2002/11/22 18:37:24 dannybackx Exp $";
+static const char rcsid[] = "$Id: FontList.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $";
 
 #include <LTconfig.h>
 #include <string.h>
@@ -33,7 +33,6 @@ static const char rcsid[] = "$Id: FontList.c,v 1.50 2002/11/22 18:37:24 dannybac
 #include <XmI/DebugUtil.h>
 
 #ifdef	USE_XFT
-#include <fontconfig/fontconfig.h>
 #include <X11/Xft/Xft.h>
 #endif
 
@@ -269,6 +268,38 @@ XmFontListCreate(XFontStruct *font, XmStringCharSet charset)
 	return r;
 }
 
+#ifdef	USE_XFT
+extern XmFontList
+XmFontListCreateXft(XftFont *font, XmStringCharSet charset)
+{
+    /* this function is obsolete 1.2 and above and should not be used.
+       Use XmFontListAppendEntry instead! */
+
+	XmFontList		r;
+	XmFontListEntry		entry;
+#if (XmVERSION > 1)
+#ifdef	LESSTIF_VERBOSE
+	static Boolean warn=False;
+
+	if (!warn) {
+		warn=True;
+		_XmWarning(NULL, "XmFontListCreate() is an obsolete function!\n");
+	}
+#endif
+#endif
+	entry = _XmFontListEntryCreate();
+
+	entry->tag = XtNewString(charset);
+	entry->type = XmFONT_IS_XFT;
+	entry->xft_font = (XtPointer)font;
+	entry->font = NULL;
+
+	r = XmFontListAppendEntry(NULL, entry);
+
+	return r;
+}
+#endif
+
 /*
  * this function is "obsolete" since 1.2 ; however Xmt uses it.
  */
@@ -440,7 +471,7 @@ XmFontListEntryLoad(Display *display,
     XmFontListEntry entry;
     XrmValue fromString, toFont, cvtArg[2];
     Boolean success = False;
-    char *p;
+    char *p, *locale;
 
     DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryLoad(%s, tag %s)\n",
 		      font_name, tag));
@@ -496,7 +527,9 @@ XmFontListEntryLoad(Display *display,
 	toFont.size = sizeof(XFontSet);
 
 	/* XtCvtStringToFontSet needs 2 arguments : display and locale */
-	cvtArg[1].addr = (XPointer)XtNewString(setlocale(LC_CTYPE, NULL))/*&"C"*/;	/* FIX ME */
+	locale = setlocale(LC_CTYPE, NULL);
+	setlocale(LC_CTYPE, locale);
+	cvtArg[1].addr = (XPointer)XtNewString(locale);
 	cvtArg[1].size = sizeof(char *);
 
 	success = XtCallConverter(display, XtCvtStringToFontSet, cvtArg,
@@ -592,6 +625,18 @@ XmFontListGetNextFont(XmFontContext context, XmStringCharSet *charset, XFontStru
 {
     context->current_entry++;
 
+#ifdef	USE_XFT_THIS_IS_BAD
+    if (context->current_entry < __XmFontListNumEntries(context->fontlist)) {
+	if (context->fontlist->renditions[context->current_entry]->type == XmFONT_IS_XFT) {
+		*font = (XFontStruct *)(context->fontlist->renditions
+			[context->current_entry]->xft_font);
+		*charset = XtNewString(context->fontlist->renditions
+			[context->current_entry]->tag);
+		return True;
+	}
+    }
+    return False;
+#else
     if (context->current_entry < __XmFontListNumEntries(context->fontlist))
     {
 	if (context->fontlist->renditions[context->current_entry]->type == XmFONT_IS_FONT)
@@ -627,6 +672,7 @@ XmFontListGetNextFont(XmFontContext context, XmStringCharSet *charset, XFontStru
     {
 	return False;
     }
+#endif
 }
 
 
@@ -743,6 +789,7 @@ _XmXftDrawDestroy(Display *dpy, Window w, XftDraw *d)
 void
 _XmXftDrawString(Display *dpy, Window wd, XmRendition r, int bpc, Position x, Position y, char *s, int len)
 {
+	XGlyphInfo	info;
 	XftDraw	*d = _XmXftDrawCreate(dpy, wd);
 
 	switch (bpc) {
@@ -757,6 +804,19 @@ _XmXftDrawString(Display *dpy, Window wd, XmRendition r, int bpc, Position x, Po
 	default:
 		_XmWarning(NULL, "_XmXftDrawString(unsupported bpc %d)\n", bpc);
 	case 1:
+#if	0	/* Experiment */
+	{
+		XftTextExtents8(dpy, r->xft_font, s, len, &info);
+		XClearArea(dpy, wd, x, y, info.width, info.height, False);
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "Clear %d %d %d %d\n",
+			x, y, info.width, info.height));
+	}
+#endif
+		/* Experiment */
+		XftTextExtents8(dpy, r->xft_font, s, len, &info);
+		XftDrawRect(d, &r->xft_background, x, y - info.height, info.width, info.height);
+		/* End experiment */
+
 		XftDrawString8(d, &r->xft_foreground, r->xft_font,
 			x, y, s, len);
 		break;
