@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/RenderTable.c,v 1.31 2002/03/01 17:04:34 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/RenderTable.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $
  *
  * Copyright (C) 1998 Free Software Foundation, Inc.
- * Copyright  1998, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1998, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/RenderTable.c,v 1.31 2002/03/01 17:04:34 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/RenderTable.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -34,6 +34,9 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Render
 
 #include <XmI/DebugUtil.h>
 
+#ifdef	USE_XFT
+#include <X11/Xft/Xft.h>
+#endif
 
 static XmRendition _XmRenditionCopy(XmRendition s)
 {
@@ -191,6 +194,15 @@ XmRenderTableGetRendition(XmRenderTable table, XmStringTag tag)
 	return NULL;
 }
 
+#ifdef	USE_XFT
+extern XmRendition
+XmeRenderTableGetXftRendition(XmRenderTable table)
+{
+	if (table == NULL || table->count == 0)
+		return NULL;
+	return _XmRenditionCopy(table->renditions[0]);
+}
+#endif
 
 extern XmRendition *
 XmRenderTableGetRenditions(XmRenderTable table,
@@ -254,19 +266,6 @@ XmeRenderTableGetDefaultFont(XmRenderTable renderTable,
 	return False;
 }
 
-#if 0
-/* This is in <XmI/XmI.h>
-struct __XmParseMappingRec {
-	XtPointer	client_data;
-	XmIncludeStatus	include_status;
-	XmParseProc	invoke_parse_proc;
-	XtPointer	pattern;
-	XmTextType	pattern_type;
-	XmString	substitute;
-};
- */
-#endif
-
 /* FIX ME
  * This is the default mapping table for XmStringGenerate().
  */
@@ -288,6 +287,7 @@ static struct __XmParseMappingRec _dft_tbl[] = {
 		NULL	/* Initialized at run time */
 	},
 };
+
 static struct __XmParseMappingRec *_dft_ptr = &_dft_tbl[0];
 static XmParseTable _XmStringGenerateDefaultTable = &_dft_ptr;
 
@@ -359,8 +359,25 @@ XmRenditionCreate(Widget widget, XmStringTag tag, ArgList al, Cardinal ac)
 	r->strike_thru_type = XmAS_IS;
 	r->tab_list = (XmTabList)XmAS_IS;
 	r->underline_type = XmAS_IS;
+
+#ifdef	USE_XFT
+	r->xft_font = NULL;
+	r->font_average_width = 0;
+	memset(&r->xft_foreground, 0, sizeof(XftColor));
+	memset(&r->xft_background, 0, sizeof(XftColor));
+	r->pattern = NULL;
+	r->font_style = NULL;
+	r->font_foundry = NULL;
+	r->font_encoding = NULL;
+	r->font_size = 0;
+	r->pixel_size = 0;
+	r->font_slant = 0;
+	r->font_spacing = 0;
+	r->font_weight = 0;
+#endif
+
 	
-#if 0
+#ifdef	DEBUG_POINTERS
 	DEBUGOUT(_LtDebug(__FILE__, widget, "XmRenditionCreate() -> %p\n", r));
 #endif
 	for (i=0; i<ac; i++) {
@@ -392,6 +409,9 @@ XmRenditionCreate(Widget widget, XmStringTag tag, ArgList al, Cardinal ac)
 		if (strcmp(al[i].name, XmNunderlineType) == 0) {
 			r->underline_type = al[i].value;
 		}
+#ifdef	USE_XFT
+		/* Xft specific resources ?? FIX ME */
+#endif
 	}
 
 	return r;
@@ -404,11 +424,49 @@ extern void XmRenditionFree(XmRendition rendition)
 	_XmRenditionFree(rendition);
 }
 
+#ifndef	XtRXftColor
+#define	XtRXftColor	"XftColor"
+#endif
 
-extern void XmRenditionUpdate(XmRendition rendition, ArgList al, Cardinal ad)
+extern void
+XmRenditionUpdate(XmRendition r, ArgList al, Cardinal ad)
 {
-	/* XXX FIX ME XXX: This is just a stub. */
+	int		i;
+	Boolean		ok;
+	Widget		w = NULL;	/* Crash !! */
+	XrmValue	to, from;
+
+	for (i=0; i<ad; i++) {
+#ifdef	USE_XFT
+		if (strcmp(al[i].name, XmNrenditionForeground) == 0) {
+			/* XftColor */
+			from.addr = &al[i].value;
+			from.size = sizeof(XtPointer);
+			to.addr = &r->xft_foreground;
+			to.size = sizeof(XftColor);
+
+			ok = XtConvertAndStore(w,
+				XmRString, &from,
+				XtRXftColor, &to);
+		} else
+		if (strcmp(al[i].name, XmNrenditionBackground) == 0) {
+			/* XftColor */
+			from.addr = &al[i].value;
+			from.size = sizeof(XtPointer);
+			to.addr = &r->xft_background;
+			to.size = sizeof(XftColor);
+			ok = XtConvertAndStore(w,
+				XmRString, &from,
+				XtRXftColor, &to);
+		} else
+#endif
+		{
+			;	/* Nothing */
+		}
+	}
+#if 0
 	_XmWarning(NULL, "XmRenditionUpdate(): not yet implemented!");
+#endif
 }
 
 
@@ -443,11 +501,39 @@ void _XmRenderTableFinaliseTag(Widget w, XmRenderTable r, char *tag)
 
 	/* FIX ME */
 	DEBUGOUT(_LtDebug(__FILE__, w, "_XmRenderTableFinaliseTag(%s)\n", tag));
-
+#if 0
+	/* Experimental start */
+	if (r->dpy == 0)
+		r->dpy = XtDisplay(w);
+	/* Experimental end */
+#endif
 	for (i=0; i<r->count; i++) {
 		if (strcmp(tag, r->renditions[i]->tag) == 0) {
-			if (r->renditions[i]->font == 0 ||
-				r->renditions[i]->font == (XFontSet)XmAS_IS) {
+#if	USE_XFT
+			if (r->renditions[i]->type == XmAS_IS) {
+				XftResult	res;
+				XftPattern	*p, *p2;
+
+				p = FcPatternCreate();
+/* Don't even specify anything	XftPatternAddString(p, XFT_FAMILY, "fixed"); */
+				p2 = XftFontMatch(XtDisplay(w), 0, p, &res);
+				r->renditions[i]->xft_font =
+					XftFontOpenPattern(XtDisplay(w), p2);
+				_XmXftFontAverageWidth(w,
+					(XtPointer)r->renditions[i]->xft_font,
+					&r->renditions[i]->font_average_width,
+					&r->renditions[i]->font_average_height);
+				r->renditions[i]->type = XmFONT_IS_XFT;
+				r->renditions[i]->font = NULL;			/* HACK */
+
+				DEBUGOUT(_LtDebug(__FILE__, w,
+					"_XmRenderTableFinaliseTag(%s): AS IS\n", tag));
+			}
+#endif
+			if (r->renditions[i]->font == 0
+				|| r->renditions[i]->type == XmAS_IS
+				|| r->renditions[i]->font == (XFontSet)XmAS_IS)
+			{
 				found = 1;
 
 				if (r->renditions[i]->font_name
@@ -501,8 +587,12 @@ void __XmRenderTableFinalise(Widget w, XmRenderTable r, _XmString xms)
 		case XmSTRING_COMPONENT_RENDITION_BEGIN:
 		case XmSTRING_COMPONENT_CHARSET:
 			_XmRenderTableFinaliseTag(w, r, xms->components[i]->data);
+			break;
+		case XmSTRING_COMPONENT_LOCALE_TEXT:
+			_XmRenderTableFinaliseTag(w, r, xms->components[i]->data);
+			break;
 		default:
-			/* Nothing to do */
+               ;       /* Nothing to do */
 		}
 	}
 }
@@ -537,7 +627,7 @@ void _XmRenderTableFinalise(Widget w, XmRenderTable r, XmString xms)
 		case XmSTRING_COMPONENT_CHARSET:
 			_XmRenderTableFinaliseTag(w, r, tag);
 		default:
-			/* Nothing to do */
+               ;       /* Nothing to do */
 		}
 		XtFree(tag);
 		XtFree(txt);
@@ -554,3 +644,31 @@ void _XmRenderTableFinalise(Widget w, XmRenderTable r, XmString xms)
 	}
 #endif
 }
+
+Boolean
+XmeUseXftFont(XmRenderTable r)
+{
+#ifdef	USE_XFT
+	if (r == NULL || r->count == 0)
+		return False;
+	if (r->renditions[0]->type == XmFONT_IS_XFT)
+		return True;
+	return False;
+#else
+	return False;
+#endif
+}
+
+XtPointer
+XmeXftFont(XmRendition r)
+{
+#ifdef	USE_XFT
+	if (r == NULL)
+		return NULL;
+	if (r->type == XmFONT_IS_XFT)
+		return r->xft_font;
+	return NULL;
+#else
+	return NULL;
+#endif
+}
